<?php

namespace Shqawe\ForumJump\XF\Admin\Controller;

use XF\Mvc\FormAction;
use XF\Mvc\ParameterBag;
use XF\Mvc\Reply\View;
use XF\Pub\Controller\AbstractController;

use Shqawe\ForumJump\XF\Entity\FjEntity;

class FjLinks extends AbstractController{



    public function actionView()
	{
        $visitor = \XF::visitor();
		if (!$visitor->hasPermission('forumJumpAdmin', 'canViewFjLinks'))
          {
               return $this->noPermission();
          }
		$fjLinks = $this->repository('Shqawe\ForumJump\XF:FjRepository')->getAllLinks();
		$viewParams = [
			'fjLinks'	=> $fjLinks
		];
		return $this->view('Shqawe\ForumJump\XF:forumJump\view', 'fj_view_links', $viewParams);
	}

    public function actionAdd()
	{
		$fjLinks = $this->em()->create('Shqawe\ForumJump\XF:FjEntity');
		return $this->forumJumpAdd($fjLinks);
	}
	
	
	protected function forumJumpAdd(FjEntity $FjEntity)
	{
		$visitor = \XF::visitor();
		if (!$visitor->hasPermission('furomJumpAdmin', 'canAddFjLinks'))
          {
               return $this->noPermission();
          }
		// $fjLinks = $this->repository('Shqawe\ForumJump\XF:FjRepository')->getAllLinks();
		$viewParams = [
			'fjLinks'	=> $FjEntity
		];
		return $this->view('Shqawe\ForumJump\XF:forumJump\add', 'fj_addEdit_links', $viewParams);
    }

    protected function forumJumpEdit(FjEntity $FjEntity)
	{
		
		$viewParams = [
			'fjLinks' => $FjEntity
		];
		return $this->view('Shqawe\ForumJump\XF:forumJump\add', 'fj_addEdit_links', $viewParams);
	}
	
	public function actionEdit(ParameterBag $params)
	{
        $fjLinks = $this->assertFjLinksExists($params['fj_id']);
        $visitor = \XF::visitor();
		if (!$visitor->hasPermission('furomJumpAdmin', 'canEditFjLinks'))
          {
               return $this->noPermission();
          }
		return $this->forumJumpEdit($fjLinks);
	}

    public function actionSave(ParameterBag $params)
	{
		$this->assertPostOnly();
		if ($params['fj_id'])
		{
			$fjLinks = $this->assertFjLinksExists($params['fj_id']);
			$form = $this->fjLinksEditSave($fjLinks);
		}
		else
		{
			$fjLinks = $this->em()->create('Shqawe\ForumJump\XF:FjEntity');
			$form = $this->pageSaveProcess($fjLinks);
		}
		
		
		if(get_class($form) === 'XF\Mvc\Reply\Error') {
			return $form;
		} else {
			$form->run();
		}

		return $this->redirect($this->buildLink('fjlinks/view'), \XF::phrase('fj_link_has_been_saved'));
    }
    

    protected function fjLinksEditSave(FjEntity $FjEntity)
	{
		$entityInput = $this->filter([
            'fj_link_title' => 'str',
            'fj_link_url' => 'str',
            'fj_link_type' => 'int',
            'fj_link_act' => 'int'
            ]);

		$form = $this->formAction();
		$form->basicEntitySave($FjEntity, $entityInput);

		return $form;
	}
	
	protected function pageSaveProcess(FjEntity $FjEntity)
	{
		$entityInput = $this->filter([
            'fj_link_title' => 'str',
            'fj_link_url' => 'str',
            'fj_link_type' => 'int',
            'fj_link_act' => 'int'
            ]);

		$form = $this->formAction();
		$form->basicEntitySave($FjEntity, $entityInput);

		return $form;
    }
    
    public function actionDelete(ParameterBag $params)
	{
		$fjLinks = $this->assertFjLinksExists($params['fj_id']);
		
		$visitor = \XF::visitor();
		if (!$visitor->hasPermission('forumJumpAdmin', 'canDeleteFjLinks'))
          {
               return $this->noPermission();
          }

		/** @var \XF\ControllerPlugin\Delete $plugin */
		$plugin = $this->plugin('XF:Delete');
		return $plugin->actionDelete(
			$fjLinks,
			$this->buildLink('fjlinks/delete', $fjLinks),
			$this->buildLink('fjlinks/edit', $fjLinks),
			$this->buildLink('fjlinks/view'),			
			$fjLinks->fj_link_title
			
		);
	}
	
	protected function assertFjLinksExists($id, $with = null, $phraseKey = null)
	{
		return $this->assertRecordExists('Shqawe\ForumJump\XF:FjEntity', $id, $with, $phraseKey);
	}
}